embassy-usb-dfu

Crates

git

Versions

dfu

Flavors

Reset

Trait Reset 

pub trait Reset {
    // Required method
    fn sys_reset(&self);
}
Provides a platform-agnostic interface for initiating a system reset.

This crate exposes ResetImmediate when compiled with cortex-m or esp32c3 support, which immediately issues a reset request without interfacing with any other peripherals.

If alternate behaviour is desired, a custom implementation of Reset can be provided as an argument to the usb_dfu function.

Required Methods

fn sys_reset(&self)

Reset the device.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Reset for ResetImmediate

Available on crate feature cortex-m only.